Cleanup networks
----------------

**Header:** ``mockturtle/algorithms/cleanup.hpp``

.. doxygenfunction:: mockturtle::cleanup_dangling(NtkSrc const&, bool, bool)
.. doxygenfunction:: mockturtle::cleanup_dangling(NtkSource const&, NtkDest&, LeavesIterator, LeavesIterator)
.. doxygenfunction:: mockturtle::cleanup_luts
